**Example 1: 删除自定义人物图片**



Input: 

```
tccli ivld DeleteCustomPersonImage --cli-unfold-argument  \
    --PersonId person-Axgo3FYc \
    --ImageId image-Axgo3FYc-GOeV
```

Output: 
```
{
    "Response": {
        "ImageId": "image-Axgo3FYc-GOeV",
        "PersonId": "person-Axgo3FYc",
        "RequestId": "88ca11c5-3ab8-4069-b2b9-723f6143d6aa"
    }
}
```

